@@ -47,10 +47,11 @@ describe 'nova::api' do
       it 'configures various stuff' do
         is_expected.to contain_nova_config('DEFAULT/instance_name_template').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('wsgi/api_paste_config').with_value('api-paste.ini')
-        is_expected.to contain_nova_config('DEFAULT/osapi_compute_listen').with_value('0.0.0.0')
-        is_expected.to contain_nova_config('DEFAULT/osapi_compute_listen_port').with_value('8774')
-        is_expected.to contain_nova_config('DEFAULT/metadata_listen').with_value('0.0.0.0')
-        is_expected.to contain_nova_config('DEFAULT/metadata_listen_port').with_value('8775')
+        is_expected.to contain_nova_config('DEFAULT/osapi_compute_listen').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('DEFAULT/osapi_compute_listen_port').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('api/use_forwarded_for').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('DEFAULT/metadata_listen').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('DEFAULT/metadata_listen_port').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/osapi_compute_workers').with_value('5')
         is_expected.to contain_nova_config('DEFAULT/metadata_workers').with_value('5')
         is_expected.to contain_oslo__middleware('nova_config').with(
@@ -149,51 +150,11 @@ describe 'nova::api' do
     context 'while not managing service state' do
       before do
         params.merge!({
-          :enabled        => false,
           :manage_service => false,
         })
       end
 
-      it { is_expected.to contain_service('nova-api').without_ensure }
-    end
-
-    context 'with default database parameters' do
-      let :pre_condition do
-        "include nova::db
-         class { 'nova::keystone::authtoken':
-           password => 'a_big_secret',
-         }"
-      end
-
-      it { is_expected.to_not contain_nova_config('database/connection') }
-      it { is_expected.to_not contain_nova_config('database/slave_connection') }
-      it { is_expected.to_not contain_nova_config('api_database/connection') }
-      it { is_expected.to_not contain_nova_config('api_database/slave_connection') }
-      it { is_expected.to_not contain_nova_config('database/connection_recycle_time').with_value('<SERVICE DEFAULT>') }
-    end
-
-    context 'with overridden database parameters' do
-      let :pre_condition do
-        "class { 'nova::db':
-           database_connection              => 'mysql://user:pass@db/db1',
-           slave_connection                 => 'mysql://user:pass@slave/db1',
-           api_database_connection          => 'mysql://user:pass@db/db2',
-           api_slave_connection             => 'mysql://user:pass@slave/db2',
-           database_connection_recycle_time => '30',
-         }
-         class { 'nova::keystone::authtoken':
-           password => 'passw0rd',
-         }
-        "
-      end
-
-      it { is_expected.to contain_nova_config('api_database/connection').with_value('mysql://user:pass@db/db2').with_secret(true) }
-      it { is_expected.to contain_nova_config('api_database/slave_connection').with_value('mysql://user:pass@slave/db2').with_secret(true) }
-      it { is_expected.to contain_oslo__db('nova_config').with(
-        :connection              => 'mysql://user:pass@db/db1',
-        :slave_connection        => 'mysql://user:pass@slave/db1',
-        :connection_recycle_time => '30',
-      )}
+      it { is_expected.to_not contain_service('nova-api') }
     end
 
     context 'with custom instance_name_template' do
@@ -261,8 +222,9 @@ describe 'nova::api' do
     context 'when running nova API in wsgi for compute, and metadata in wsgi' do
       before do
         params.merge!({
-          :service_name => 'httpd',
-          :nova_metadata_wsgi_enabled => true })
+          :service_name               => 'httpd',
+          :nova_metadata_wsgi_enabled => true
+        })
       end
 
       let :pre_condition do
@@ -274,12 +236,15 @@ describe 'nova::api' do
       end
 
       it 'disable nova API service' do
-          is_expected.to contain_service('nova-api').with(
+        is_expected.to contain_service('nova-api').with(
           :ensure => 'stopped',
           :name   => platform_params[:nova_api_service],
           :enable => false,
           :tag    => 'nova-service',
         )
+        is_expected.to contain_nova_config('DEFAULT/metadata_workers').with_ensure('absent')
+        is_expected.to contain_nova_config('DEFAULT/metadata_listen').with_ensure('absent')
+        is_expected.to contain_nova_config('DEFAULT/metadata_listen_port').with_ensure('absent')
       end
 
     end
@@ -323,7 +288,7 @@ describe 'nova::api' do
       end
 
       let (:platform_params) do
-        case facts[:osfamily]
+        case facts[:os]['family']
         when 'Debian'
           { :nova_api_package => 'nova-api',
             :nova_api_service => 'nova-api' }
@@ -333,7 +298,7 @@ describe 'nova::api' do
         end
       end
       it_behaves_like 'nova-api'
-      if facts[:operatingsystem] == 'Debian'
+      if facts[:os]['name'] == 'Debian'
         it_behaves_like 'nova-api on Debian'
       end
     end
