@@ -26,14 +26,15 @@ describe 'nova' do
       end
 
       it 'does not configure auth_strategy' do
-        is_expected.not_to contain_nova_config('api/auth_strategy')
+        is_expected.to contain_nova_config('api/auth_strategy').with_value('<SERVICE DEFAULT>')
       end
 
       it 'configures rabbit' do
         is_expected.to contain_oslo__messaging__default('nova_config').with(
-          :transport_url        => '<SERVICE DEFAULT>',
-          :rpc_response_timeout => '<SERVICE DEFAULT>',
-          :control_exchange     => '<SERVICE DEFAULT>',
+          :executor_thread_pool_size => '<SERVICE DEFAULT>',
+          :transport_url             => '<SERVICE DEFAULT>',
+          :rpc_response_timeout      => '<SERVICE DEFAULT>',
+          :control_exchange          => '<SERVICE DEFAULT>',
         )
         is_expected.to contain_oslo__messaging__rabbit('nova_config').with(
           :rabbit_use_ssl              => '<SERVICE DEFAULT>',
@@ -90,7 +91,7 @@ describe 'nova' do
         is_expected.to contain_nova_config('DEFAULT/initial_cpu_allocation_ratio').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/initial_ram_allocation_ratio').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/initial_disk_allocation_ratio').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('DEFAULT/ssl_only').with_value(false)
+        is_expected.to contain_nova_config('DEFAULT/ssl_only').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/cert').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/key').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('console/ssl_ciphers').with_value('<SERVICE DEFAULT>')
@@ -111,6 +112,7 @@ describe 'nova' do
           :rpc_response_timeout                    => '30',
           :long_rpc_timeout                        => '1800',
           :control_exchange                        => 'nova',
+          :executor_thread_pool_size               => 64,
           :rabbit_use_ssl                          => true,
           :rabbit_heartbeat_timeout_threshold      => '60',
           :rabbit_heartbeat_rate                   => '10',
@@ -182,9 +184,10 @@ describe 'nova' do
 
       it 'configures rabbit' do
         is_expected.to contain_oslo__messaging__default('nova_config').with(
-          :transport_url        => 'rabbit://rabbit_user:password@localhost:5673',
-          :rpc_response_timeout => '30',
-          :control_exchange     => 'nova',
+          :executor_thread_pool_size => 64,
+          :transport_url             => 'rabbit://rabbit_user:password@localhost:5673',
+          :rpc_response_timeout      => '30',
+          :control_exchange          => 'nova',
         )
         is_expected.to contain_oslo__messaging__rabbit('nova_config').with(
           :rabbit_use_ssl              => true,
@@ -465,6 +468,14 @@ describe 'nova' do
       it { is_expected.to contain_nova_config('DEFAULT/initial_disk_allocation_ratio').with_value(3.0) }
     end
 
+    context 'with array used for console_ssl_ciphers' do
+      let :params do
+        {
+          :console_ssl_ciphers => ['kEECDH+aECDSA+AES', 'kEECDH+AES+aRSA', 'kEDH+aRSA+AES']
+        }
+      end
+      it {is_expected.to contain_nova_config('console/ssl_ciphers').with_value('kEECDH+aECDSA+AES:kEECDH+AES+aRSA:kEDH+aRSA+AES') }
+    end
   end
 
 
@@ -476,7 +487,7 @@ describe 'nova' do
         facts.merge!(OSDefaults.get_facts())
       end
 
-      case facts[:osfamily]
+      case facts[:os]['family']
       when 'Debian'
         let (:platform_params) do
           { :nova_common_package => 'nova-common',
