@@ -33,33 +33,15 @@ describe 'nova::migration::libvirt' do
   shared_examples_for 'nova migration with libvirt' do
 
     context 'with default params' do
-      it { is_expected.to contain_libvirtd_config('listen_tls').with_value('0') }
-      it { is_expected.to contain_libvirtd_config('listen_tcp').with_value('1') }
       it { is_expected.to contain_libvirtd_config('auth_tls').with_value('<SERVICE DEFAULT>').with_quote(true) }
       it { is_expected.to contain_libvirtd_config('auth_tcp').with_value('none').with_quote(true) }
       it { is_expected.to contain_libvirtd_config('ca_file').with_value('<SERVICE DEFAULT>').with_quote(true) }
       it { is_expected.to contain_libvirtd_config('crl_file').with_value('<SERVICE DEFAULT>').with_quote(true) }
       it { is_expected.to contain_nova_config('libvirt/live_migration_tunnelled').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('libvirt/live_migration_with_native_tls').with_value('<SERVICE DEFAULT>') }
-      it { is_expected.to contain_nova_config('libvirt/live_migration_completion_timeout').with_value('<SERVICE DEFAULT>') }
-      it { is_expected.to contain_nova_config('libvirt/live_migration_timeout_action').with_value('<SERVICE DEFAULT>') }
-      it { is_expected.to contain_nova_config('libvirt/live_migration_uri').with_value('qemu+tcp://%s/system') }
-      it { is_expected.to contain_nova_config('libvirt/live_migration_inbound_addr').with_value('<SERVICE DEFAULT>')}
-      it { is_expected.to contain_nova_config('libvirt/live_migration_permit_post_copy').with_value('<SERVICE DEFAULT>')}
-      it { is_expected.to contain_nova_config('libvirt/live_migration_permit_auto_converge').with_value('<SERVICE DEFAULT>')}
-    end
-
-    context 'with modular_libvirt set to true' do
-      let(:params) { { :modular_libvirt => true} }
-
-      it { is_expected.to contain_virtproxyd_config('listen_tls').with_value('0') }
-      it { is_expected.to contain_virtproxyd_config('listen_tcp').with_value('1') }
-      it { is_expected.to contain_virtproxyd_config('auth_tls').with_value('<SERVICE DEFAULT>').with_quote(true) }
-      it { is_expected.to contain_virtproxyd_config('auth_tcp').with_value('none').with_quote(true) }
-      it { is_expected.to contain_virtproxyd_config('ca_file').with_value('<SERVICE DEFAULT>').with_quote(true) }
-      it { is_expected.to contain_virtproxyd_config('crl_file').with_value('<SERVICE DEFAULT>').with_quote(true) }
-      it { is_expected.to contain_nova_config('libvirt/live_migration_tunnelled').with_value('<SERVICE DEFAULT>') }
-      it { is_expected.to contain_nova_config('libvirt/live_migration_with_native_tls').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('libvirt/live_migration_downtime').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('libvirt/live_migration_downtime_steps').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('libvirt/live_migration_downtime_delay').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('libvirt/live_migration_completion_timeout').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('libvirt/live_migration_timeout_action').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('libvirt/live_migration_uri').with_value('qemu+tcp://%s/system') }
@@ -109,8 +91,6 @@ describe 'nova::migration::libvirt' do
           :transport => 'tls',
         }
       end
-      it { is_expected.to contain_libvirtd_config('listen_tls').with_value('1') }
-      it { is_expected.to contain_libvirtd_config('listen_tcp').with_value('0') }
       it { is_expected.to contain_libvirtd_config('auth_tls').with_value('none').with_quote(true) }
       it { is_expected.to contain_libvirtd_config('auth_tcp').with_value('<SERVICE DEFAULT>').with_quote(true) }
       it { is_expected.to contain_libvirtd_config('ca_file').with_value('<SERVICE DEFAULT>').with_quote(true) }
@@ -118,23 +98,6 @@ describe 'nova::migration::libvirt' do
       it { is_expected.to contain_nova_config('libvirt/live_migration_uri').with_value('qemu+tls://%s/system')}
     end
 
-    context 'with tls enabled and modular-libvirt set to true' do
-      let :params do
-        {
-          :transport => 'tls',
-          :modular_libvirt => true,
-        }
-      end
-      it { is_expected.to contain_virtproxyd_config('listen_tls').with_value('1') }
-      it { is_expected.to contain_virtproxyd_config('listen_tcp').with_value('0') }
-      it { is_expected.to contain_virtproxyd_config('auth_tls').with_value('none').with_quote(true) }
-      it { is_expected.to contain_virtproxyd_config('auth_tcp').with_value('<SERVICE DEFAULT>').with_quote(true) }
-      it { is_expected.to contain_virtproxyd_config('ca_file').with_value('<SERVICE DEFAULT>').with_quote(true) }
-      it { is_expected.to contain_virtproxyd_config('crl_file').with_value('<SERVICE DEFAULT>').with_quote(true) }
-      it { is_expected.to contain_nova_config('libvirt/live_migration_uri').with_value('qemu+tls://%s/system')}
-    end
-
-
     context 'with tls enabled and inbound addr set' do
       let :params do
         {
@@ -142,8 +105,6 @@ describe 'nova::migration::libvirt' do
           :live_migration_inbound_addr => 'host1.example.com',
         }
       end
-      it { is_expected.to contain_libvirtd_config('listen_tls').with_value('1') }
-      it { is_expected.to contain_libvirtd_config('listen_tcp').with_value('0') }
       it { is_expected.to contain_libvirtd_config('auth_tls').with_value('none').with_quote(true) }
       it { is_expected.to contain_libvirtd_config('auth_tcp').with_value('<SERVICE DEFAULT>').with_quote(true) }
       it { is_expected.to contain_libvirtd_config('ca_file').with_value('<SERVICE DEFAULT>').with_quote(true) }
@@ -165,11 +126,17 @@ describe 'nova::migration::libvirt' do
       let :params do
         {
           :live_migration_tunnelled          => true,
+          :live_migration_downtime           => 800,
+          :live_migration_downtime_steps     => 15,
+          :live_migration_downtime_delay     => 5,
           :live_migration_completion_timeout => '1500',
           :live_migration_timeout_action     => 'force_complete',
         }
       end
       it { is_expected.to contain_nova_config('libvirt/live_migration_tunnelled').with(:value => true) }
+      it { is_expected.to contain_nova_config('libvirt/live_migration_downtime').with_value(800) }
+      it { is_expected.to contain_nova_config('libvirt/live_migration_downtime_steps').with_value(15) }
+      it { is_expected.to contain_nova_config('libvirt/live_migration_downtime_delay').with_value(5) }
       it { is_expected.to contain_nova_config('libvirt/live_migration_completion_timeout').with_value('1500') }
       it { is_expected.to contain_nova_config('libvirt/live_migration_timeout_action').with_value('force_complete') }
     end
@@ -197,20 +164,6 @@ describe 'nova::migration::libvirt' do
       it { is_expected.to contain_libvirtd_config('crl_file').with_value('<SERVICE DEFAULT>').with_quote(true) }
     end
 
-    context 'with auth set to sasl and modular_libvirt is true' do
-      let :params do
-        {
-          :auth => 'sasl',
-          :modular_libvirt => true,
-        }
-      end
-      it { is_expected.to contain_virtproxyd_config('auth_tls').with_value('<SERVICE DEFAULT>').with_quote(true) }
-      it { is_expected.to contain_virtproxyd_config('auth_tcp').with_value('sasl').with_quote(true) }
-      it { is_expected.to contain_virtproxyd_config('ca_file').with_value('<SERVICE DEFAULT>').with_quote(true) }
-      it { is_expected.to contain_virtproxyd_config('crl_file').with_value('<SERVICE DEFAULT>').with_quote(true) }
-    end
-
-
     context 'with auth set to sasl and tls enabled' do
       let :params do
         {
@@ -224,21 +177,6 @@ describe 'nova::migration::libvirt' do
       it { is_expected.to contain_libvirtd_config('crl_file').with_value('<SERVICE DEFAULT>').with_quote(true) }
     end
 
-    context 'with auth set to sasl and tls enabled and modular_libvirt set to true' do
-      let :params do
-        {
-          :auth            => 'sasl',
-          :transport       => 'tls',
-          :modular_libvirt => true,
-        }
-      end
-      it { is_expected.to contain_virtproxyd_config('auth_tls').with_value('sasl').with_quote(true) }
-      it { is_expected.to contain_virtproxyd_config('auth_tcp').with_value('<SERVICE DEFAULT>').with_quote(true) }
-      it { is_expected.to contain_virtproxyd_config('ca_file').with_value('<SERVICE DEFAULT>').with_quote(true) }
-      it { is_expected.to contain_virtproxyd_config('crl_file').with_value('<SERVICE DEFAULT>').with_quote(true) }
-    end
-
-
     context 'with certificates set and tls enabled' do
       let :params do
         {
@@ -253,21 +191,6 @@ describe 'nova::migration::libvirt' do
       it { is_expected.to contain_libvirtd_config('crl_file').with_value('/crl').with_quote(true) }
     end
 
-    context 'with certificates set and tls enabled and modular_libvirt set to true' do
-      let :params do
-        {
-          :transport       => 'tls',
-          :ca_file         => '/ca',
-          :crl_file        => '/crl',
-          :modular_libvirt => true,
-        }
-      end
-      it { is_expected.to contain_virtproxyd_config('auth_tls').with_value('none').with_quote(true) }
-      it { is_expected.to contain_virtproxyd_config('auth_tcp').with_value('<SERVICE DEFAULT>').with_quote(true) }
-      it { is_expected.to contain_virtproxyd_config('ca_file').with_value('/ca').with_quote(true) }
-      it { is_expected.to contain_virtproxyd_config('crl_file').with_value('/crl').with_quote(true) }
-    end
-
     context 'with auth set to an invalid setting' do
       let :params do
         {
@@ -284,8 +207,10 @@ describe 'nova::migration::libvirt' do
           :configure_libvirt => false
         }
       end
-      it { is_expected.not_to contain_libvirtd_config('listen_tls') }
-      it { is_expected.not_to contain_libvirtd_config('listen_tcp') }
+      it { is_expected.to_not contain_libvirtd_config('auth_tls') }
+      it { is_expected.to_not contain_libvirtd_config('auth_tcp') }
+      it { is_expected.to_not contain_libvirtd_config('ca_file') }
+      it { is_expected.to_not contain_libvirtd_config('crl_file') }
     end
 
     context 'when not configuring nova and tls enabled' do
@@ -298,25 +223,6 @@ describe 'nova::migration::libvirt' do
       it { is_expected.not_to contain_nova_config('libvirt/live_migration_uri').with_value('qemu+tls://%s/system') }
     end
 
-    context 'with listen_address set' do
-      let :params do
-        {
-          :listen_address => "127.0.0.1"
-        }
-      end
-      it { is_expected.to contain_libvirtd_config('listen_addr').with_value('127.0.0.1').with_quote(true) }
-    end
-
-    context 'with listen_address set and modular_libvirt set to true' do
-      let :params do
-        {
-          :listen_address => "127.0.0.1",
-          :modular_libvirt => true,
-        }
-      end
-      it { is_expected.to contain_virtproxyd_config('listen_addr').with_value('127.0.0.1').with_quote(true) }
-    end
-
     context 'with ssh transport' do
       let :params do
         {
@@ -324,20 +230,6 @@ describe 'nova::migration::libvirt' do
         }
       end
       it { is_expected.to contain_nova_config('libvirt/live_migration_uri').with_value('qemu+ssh://%s/system')}
-      it { is_expected.to contain_libvirtd_config('listen_tls').with_value('0') }
-      it { is_expected.to contain_libvirtd_config('listen_tcp').with_value('0') }
-    end
-
-    context 'with ssh transport and modular_libvirt set to true' do
-      let :params do
-        {
-          :transport       => 'ssh',
-          :modular_libvirt => true,
-        }
-      end
-      it { is_expected.to contain_nova_config('libvirt/live_migration_uri').with_value('qemu+ssh://%s/system')}
-      it { is_expected.to contain_virtproxyd_config('listen_tls').with_value('0') }
-      it { is_expected.to contain_virtproxyd_config('listen_tcp').with_value('0') }
     end
 
     context 'with ssh transport with user' do
@@ -348,21 +240,6 @@ describe 'nova::migration::libvirt' do
         }
       end
       it { is_expected.to contain_nova_config('libvirt/live_migration_uri').with_value('qemu+ssh://foobar@%s/system')}
-      it { is_expected.to contain_libvirtd_config('listen_tls').with_value('0') }
-      it { is_expected.to contain_libvirtd_config('listen_tcp').with_value('0') }
-    end
-
-    context 'with ssh transport with user and modular_libvirt set to true' do
-      let :params do
-        {
-          :transport => 'ssh',
-          :client_user => 'foobar',
-          :modular_libvirt => true,
-        }
-      end
-      it { is_expected.to contain_nova_config('libvirt/live_migration_uri').with_value('qemu+ssh://foobar@%s/system')}
-      it { is_expected.to contain_virtproxyd_config('listen_tls').with_value('0') }
-      it { is_expected.to contain_virtproxyd_config('listen_tcp').with_value('0') }
     end
 
     context 'with ssh transport with port' do
@@ -373,21 +250,6 @@ describe 'nova::migration::libvirt' do
         }
       end
       it { is_expected.to contain_nova_config('libvirt/live_migration_uri').with_value('qemu+ssh://%s:1234/system')}
-      it { is_expected.to contain_libvirtd_config('listen_tls').with_value('0') }
-      it { is_expected.to contain_libvirtd_config('listen_tcp').with_value('0') }
-    end
-
-    context 'with ssh transport with port and modular_libvirt set to true' do
-      let :params do
-        {
-          :transport       => 'ssh',
-          :client_port     => 1234,
-          :modular_libvirt => true,
-        }
-      end
-      it { is_expected.to contain_nova_config('libvirt/live_migration_uri').with_value('qemu+ssh://%s:1234/system')}
-      it { is_expected.to contain_virtproxyd_config('listen_tls').with_value('0') }
-      it { is_expected.to contain_virtproxyd_config('listen_tcp').with_value('0') }
     end
 
     context 'with ssh transport with extraparams' do
@@ -398,23 +260,7 @@ describe 'nova::migration::libvirt' do
         }
       end
       it { is_expected.to contain_nova_config('libvirt/live_migration_uri').with_value('qemu+ssh://%s/system?foo=%%25&bar=baz')}
-      it { is_expected.to contain_libvirtd_config('listen_tls').with_value('0') }
-      it { is_expected.to contain_libvirtd_config('listen_tcp').with_value('0') }
     end
-
-    context 'with ssh transport with extraparams and modular_libvirt set to true' do
-      let :params do
-        {
-          :transport => 'ssh',
-          :client_extraparams => {'foo' => '%', 'bar' => 'baz'},
-          :modular_libvirt => true,
-        }
-      end
-      it { is_expected.to contain_nova_config('libvirt/live_migration_uri').with_value('qemu+ssh://%s/system?foo=%%25&bar=baz')}
-      it { is_expected.to contain_virtproxyd_config('listen_tls').with_value('0') }
-      it { is_expected.to contain_virtproxyd_config('listen_tcp').with_value('0') }
-    end
-
   end
 
   shared_examples_for 'nova migration with libvirt in Debian' do
@@ -424,16 +270,19 @@ describe 'nova::migration::libvirt' do
       end
 
       it { is_expected.to contain_file_line('/etc/default/libvirtd libvirtd opts').with(
-        :path  => '/etc/default/libvirtd',
-        :line  => 'libvirtd_opts=',
-        :match => 'libvirtd_opts=',
-        :tag   => 'libvirt-file_line',
+        :ensure            => 'absent',
+        :path              => '/etc/default/libvirtd',
+        :match             => '^libvirtd_opts=$',
+        :match_for_absence => true,
       ) }
       it { is_expected.to contain_service('libvirtd-tls').with(
         :name   => 'libvirtd-tls.socket',
         :ensure => 'running',
         :enable => true,
-        )}
+      )}
+      it { is_expected.to contain_file('/etc/systemd/system/libvirtd-tls.socket').with(
+        :ensure => 'absent',
+      )}
     end
 
     context 'with tcp transport' do
@@ -442,45 +291,18 @@ describe 'nova::migration::libvirt' do
       end
 
       it { is_expected.to contain_file_line('/etc/default/libvirtd libvirtd opts').with(
-        :path  => '/etc/default/libvirtd',
-        :line  => 'libvirtd_opts=',
-        :match => 'libvirtd_opts=',
-        :tag   => 'libvirt-file_line',
+        :ensure            => 'absent',
+        :path              => '/etc/default/libvirtd',
+        :match             => '^libvirtd_opts=$',
+        :match_for_absence => true,
       ) }
       it { is_expected.to contain_service('libvirtd-tcp').with(
         :name   => 'libvirtd-tcp.socket',
         :ensure => 'running',
         :enable => true,
-        )}
-    end
-
-    context 'with tls transport and modular daemons' do
-      let :params do
-        {
-          :transport       => 'tls',
-          :modular_libvirt => true,
-        }
-      end
-
-      it { is_expected.to contain_service('virtproxyd-tls').with(
-        :name   => 'virtproxyd-tls.socket',
-        :ensure => 'running',
-        :enable => true,
       )}
-    end
-
-    context 'with tcp transport and modular daemons' do
-      let :params do
-        {
-          :transport       => 'tcp',
-          :modular_libvirt => true,
-        }
-      end
-
-      it { is_expected.to contain_service('virtproxyd-tcp').with(
-        :name   => 'virtproxyd-tcp.socket',
-        :ensure => 'running',
-        :enable => true,
+      it { is_expected.to contain_file('/etc/systemd/system/libvirtd-tcp.socket').with(
+        :ensure => 'absent',
       )}
     end
   end
@@ -492,51 +314,169 @@ describe 'nova::migration::libvirt' do
       end
 
       it { is_expected.to contain_file('/etc/sysconfig/libvirtd').with(
-        :ensure => 'present',
+        :ensure => 'absent',
         :path   => '/etc/sysconfig/libvirtd',
         :tag    => 'libvirt-file',
       )}
-      it { is_expected.to contain_file_line('/etc/sysconfig/libvirtd libvirtd args').with(
-        :path  => '/etc/sysconfig/libvirtd',
-        :line  => 'LIBVIRTD_ARGS=',
-        :match => '^LIBVIRTD_ARGS=',
-        :tag   => 'libvirt-file_line',
-      )}
       it { is_expected.to contain_service('libvirtd-tls').with(
         :name   => 'libvirtd-tls.socket',
         :ensure => 'running',
         :enable => true,
       )}
+      it { is_expected.to contain_file('/etc/systemd/system/libvirtd-tls.socket').with(
+        :ensure => 'absent',
+      )}
     end
 
     context 'with tcp transport' do
       let :params do
-        { :transport => 'tcp' }
+        {
+          :transport      => 'tcp',
+          :listen_address => '127.0.0.1'
+        }
       end
 
       it { is_expected.to contain_file('/etc/sysconfig/libvirtd').with(
-        :ensure => 'present',
+        :ensure => 'absent',
         :path   => '/etc/sysconfig/libvirtd',
         :tag    => 'libvirt-file',
       )}
-      it { is_expected.to contain_file_line('/etc/sysconfig/libvirtd libvirtd args').with(
-        :path  => '/etc/sysconfig/libvirtd',
-        :line  => 'LIBVIRTD_ARGS=',
-        :match => '^LIBVIRTD_ARGS=',
-        :tag   => 'libvirt-file_line',
-      )}
       it { is_expected.to contain_service('libvirtd-tcp').with(
         :name   => 'libvirtd-tcp.socket',
         :ensure => 'running',
         :enable => true,
       )}
+      it { is_expected.to contain_file_line('libvirtd-tcp.socket ListenStream').with(
+        :path  => '/etc/systemd/system/libvirtd-tcp.socket',
+        :line  => 'ListenStream=127.0.0.1:16509',
+        :match => '^ListenStream=.*',
+      )}
+    end
+  end
+
+  shared_examples_for 'nova migration with modular libvirt' do
+    context 'with modular_libvirt set to true' do
+      let(:params) { { :modular_libvirt => true} }
+
+      it { is_expected.to contain_virtproxyd_config('auth_tls').with_value('<SERVICE DEFAULT>').with_quote(true) }
+      it { is_expected.to contain_virtproxyd_config('auth_tcp').with_value('none').with_quote(true) }
+      it { is_expected.to contain_virtproxyd_config('ca_file').with_value('<SERVICE DEFAULT>').with_quote(true) }
+      it { is_expected.to contain_virtproxyd_config('crl_file').with_value('<SERVICE DEFAULT>').with_quote(true) }
+      it { is_expected.to contain_nova_config('libvirt/live_migration_tunnelled').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('libvirt/live_migration_with_native_tls').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('libvirt/live_migration_completion_timeout').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('libvirt/live_migration_timeout_action').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('libvirt/live_migration_uri').with_value('qemu+tcp://%s/system') }
+      it { is_expected.to contain_nova_config('libvirt/live_migration_inbound_addr').with_value('<SERVICE DEFAULT>')}
+      it { is_expected.to contain_nova_config('libvirt/live_migration_permit_post_copy').with_value('<SERVICE DEFAULT>')}
+      it { is_expected.to contain_nova_config('libvirt/live_migration_permit_auto_converge').with_value('<SERVICE DEFAULT>')}
     end
 
-    context 'with tls transport and modular daemons' do
+    context 'with tls enabled' do
+      let :params do
+        {
+          :transport => 'tls',
+          :modular_libvirt => true,
+        }
+      end
+      it { is_expected.to contain_virtproxyd_config('auth_tls').with_value('none').with_quote(true) }
+      it { is_expected.to contain_virtproxyd_config('auth_tcp').with_value('<SERVICE DEFAULT>').with_quote(true) }
+      it { is_expected.to contain_virtproxyd_config('ca_file').with_value('<SERVICE DEFAULT>').with_quote(true) }
+      it { is_expected.to contain_virtproxyd_config('crl_file').with_value('<SERVICE DEFAULT>').with_quote(true) }
+      it { is_expected.to contain_nova_config('libvirt/live_migration_uri').with_value('qemu+tls://%s/system')}
+    end
+
+    context 'with auth set to sasl' do
+      let :params do
+        {
+          :auth => 'sasl',
+          :modular_libvirt => true,
+        }
+      end
+      it { is_expected.to contain_virtproxyd_config('auth_tls').with_value('<SERVICE DEFAULT>').with_quote(true) }
+      it { is_expected.to contain_virtproxyd_config('auth_tcp').with_value('sasl').with_quote(true) }
+      it { is_expected.to contain_virtproxyd_config('ca_file').with_value('<SERVICE DEFAULT>').with_quote(true) }
+      it { is_expected.to contain_virtproxyd_config('crl_file').with_value('<SERVICE DEFAULT>').with_quote(true) }
+    end
+
+    context 'with auth set to sasl and tls enabled' do
+      let :params do
+        {
+          :auth            => 'sasl',
+          :transport       => 'tls',
+          :modular_libvirt => true,
+        }
+      end
+      it { is_expected.to contain_virtproxyd_config('auth_tls').with_value('sasl').with_quote(true) }
+      it { is_expected.to contain_virtproxyd_config('auth_tcp').with_value('<SERVICE DEFAULT>').with_quote(true) }
+      it { is_expected.to contain_virtproxyd_config('ca_file').with_value('<SERVICE DEFAULT>').with_quote(true) }
+      it { is_expected.to contain_virtproxyd_config('crl_file').with_value('<SERVICE DEFAULT>').with_quote(true) }
+    end
+
+    context 'with certificates set and tls enabled' do
+      let :params do
+        {
+          :transport       => 'tls',
+          :ca_file         => '/ca',
+          :crl_file        => '/crl',
+          :modular_libvirt => true,
+        }
+      end
+      it { is_expected.to contain_virtproxyd_config('auth_tls').with_value('none').with_quote(true) }
+      it { is_expected.to contain_virtproxyd_config('auth_tcp').with_value('<SERVICE DEFAULT>').with_quote(true) }
+      it { is_expected.to contain_virtproxyd_config('ca_file').with_value('/ca').with_quote(true) }
+      it { is_expected.to contain_virtproxyd_config('crl_file').with_value('/crl').with_quote(true) }
+    end
+
+    context 'with ssh transport' do
+      let :params do
+        {
+          :transport       => 'ssh',
+          :modular_libvirt => true,
+        }
+      end
+      it { is_expected.to contain_nova_config('libvirt/live_migration_uri').with_value('qemu+ssh://%s/system')}
+    end
+
+    context 'with ssh transport with user' do
+      let :params do
+        {
+          :transport => 'ssh',
+          :client_user => 'foobar',
+          :modular_libvirt => true,
+        }
+      end
+      it { is_expected.to contain_nova_config('libvirt/live_migration_uri').with_value('qemu+ssh://foobar@%s/system')}
+    end
+
+    context 'with ssh transport with port' do
+      let :params do
+        {
+          :transport       => 'ssh',
+          :client_port     => 1234,
+          :modular_libvirt => true,
+        }
+      end
+      it { is_expected.to contain_nova_config('libvirt/live_migration_uri').with_value('qemu+ssh://%s:1234/system')}
+    end
+
+    context 'with ssh transport with extraparams' do
+      let :params do
+        {
+          :transport => 'ssh',
+          :client_extraparams => {'foo' => '%', 'bar' => 'baz'},
+          :modular_libvirt => true,
+        }
+      end
+      it { is_expected.to contain_nova_config('libvirt/live_migration_uri').with_value('qemu+ssh://%s/system?foo=%%25&bar=baz')}
+    end
+
+    context 'with tls transport' do
       let :params do
         {
           :transport       => 'tls',
           :modular_libvirt => true,
+          :listen_address  => '::1'
         }
       end
 
@@ -545,9 +485,14 @@ describe 'nova::migration::libvirt' do
         :ensure => 'running',
         :enable => true,
       )}
+      it { is_expected.to contain_file_line('virtproxyd-tls.socket ListenStream').with(
+        :path  => '/etc/systemd/system/virtproxyd-tls.socket',
+        :line  => 'ListenStream=[::1]:16514',
+        :match => '^ListenStream=.*',
+      )}
     end
 
-    context 'with tcp transport and modular daemons' do
+    context 'with tcp transport' do
       let :params do
         {
           :transport       => 'tcp',
@@ -560,6 +505,9 @@ describe 'nova::migration::libvirt' do
         :ensure => 'running',
         :enable => true,
       )}
+      it { is_expected.to contain_file('/etc/systemd/system/virtproxyd-tcp.socket').with(
+        :ensure => 'absent',
+      )}
     end
   end
 
@@ -568,15 +516,13 @@ describe 'nova::migration::libvirt' do
   }).each do |os,facts|
     context "on #{os}" do
       let (:facts) do
-        facts.merge!(OSDefaults.get_facts({ :os_workers => 5 }))
+        facts.merge!(OSDefaults.get_facts())
       end
 
       it_behaves_like 'nova migration with libvirt'
-      case facts[:osfamily]
-      when 'Debian'
-        it_behaves_like 'nova migration with libvirt in Debian'
-      when 'RedHat'
-        it_behaves_like 'nova migration with libvirt in RedHat'
+      it_behaves_like "nova migration with libvirt in #{facts[:os]['family']}"
+      if facts['osfamily'] == 'RedHat'
+        it_behaves_like 'nova migration with modulr libvirt'
       end
     end
   end
